"use client"

import CustomCard from "@/components/card/Card";
import { Box, Button, Flex, FormControl, FormLabel, Icon, Text, useColorModeValue, useToast } from "@chakra-ui/react";
import FormComponent from "@/components/form/Form";
import { InputWrapper } from "@/components/fields/Fields";
import prepareValidationSchema, { FormObject } from "@/utils/validation-schema";
import { useEffect, useMemo, useRef, useState } from "react";
import { useRouter } from "next/navigation";
import { RiCoinFill } from "react-icons/ri";
import { createCoinRequest } from "@/app/lib/coin-request/action";
import { useGeneral } from "@/contexts/GeneralContext";

const formFields: FormObject[] = [
  {
    name: "coins",
    label: "Token",
    type: "number",
    defaultValue: 0,
    min:1,
    required: true,
  },
];

interface formValues {
  coins: string;
}

export default function CoinRequest({ availableCoins }: { availableCoins:number }) {
  // Chakra imports
  const { isAdmin } = useGeneral();
  const toast = useToast();
  const router = useRouter();

  const textColor = useColorModeValue("secondaryGray.900", "white");
  const brandStars = useColorModeValue("brand.500", "brand.400");
  const coinColor = useColorModeValue("yellow.500", "yellow.400");

  // logic values
  const formRef = useRef(null);
  const formDetails = useMemo(() => prepareValidationSchema(formFields), []);
  const [coinForm, setCoinForm] = useState({});
  const { initialFormData, validationSchema } = formDetails;
  const [formValidationSchema, setFormValidationSchema] = useState({});

  useEffect(() => {
    setCoinForm(initialFormData);
    setFormValidationSchema(validationSchema);
  }, [initialFormData, validationSchema]);

  const handleSubmit = async (values: formValues, data: any) => {
    
    const payload = {
      coins: parseInt(values.coins),
    };
    const res = await createCoinRequest(payload);
    
    if (res.status == 200) {
      toast({
        title: "200",
        description: res.message,
        status: "success",
        position: "top-right",
        duration: 2000,
        isClosable: true,
      });
      data.resetForm();
      router.refresh();
    } else {
      toast({
        title: res.status,
        description: res.error,
        status: "error",
        position: "top-right",
        duration: 9000,
        isClosable: true,
      });
    }
  };

  if(isAdmin){
    return null 
  }



  return (
    <CustomCard w="100%">
      <Flex align="center" justifyContent="space-between" w="100%" px="15px" py="10px">
        <Text color={textColor} fontSize="xl" fontWeight="700" lineHeight="100%">
          Coin Request
        </Text>
        <Box display="flex" gap="2">
          <Icon as={RiCoinFill} color={coinColor} w="20px" h="20px" />
          <Text color={textColor} fontSize="xl" fontWeight="700" lineHeight="100%">
            : {availableCoins.toFixed(2)}
          </Text>
        </Box>
      </Flex>
      <Flex align="center" w="100%">
        <FormComponent
          ref={formRef}
          validationSchema={formValidationSchema}
          initialValues={coinForm}
          submitForm={(formValues, formData) => {
            handleSubmit(formValues, formData);
          }}>
          <FormControl w="full">
            <Box w="50%">
              <Box>
                <FormLabel display="flex" ms="4px" fontSize="sm" fontWeight="500" color={textColor} mb="8px">
                  Coins<Text color={brandStars}>*</Text>
                </FormLabel>
                <InputWrapper form={true} fieldName="coins" defaultValue="0" id="coins" placeholder="3000" variant="auth" w="full" mb="2px" fontSize="sm" ms={{ base: "0px", md: "0px" }} type="number" fontWeight="500" size="lg" />
              </Box>
              <Button fontSize="sm" type="submit" variant="brand" fontWeight="500" h="50" mb="28px">
                Request
              </Button>
            </Box>
          </FormControl>
        </FormComponent>
      </Flex>
    </CustomCard>
  );
}